<?php

if (!defined('SMF'))
	die('Hacking attempt...');
	
require_once(dirname(__FILE__) . '/xmlhelper.php');
require_once(dirname(__FILE__) . '/HTTPDownloader.php');
require_once(dirname(__FILE__) . '/LocalFileReader.php');

define('DEFAULT_ICON_WOWHEAD', 'INV_Misc_QuestionMark');

// The main interface to the Wowhead
class WoWHeadDC14
{
	var $xml_helper;
	var $method = 'find'; //set default to find...
	var $colornames;
	
	// Constructor
	function WoWHeadDC14($method)
	{
		$this->xml_helper = new XmlHelperDC14();
		$this->colornames['q0'] = "greyname";
		$this->colornames['q1'] = "whitename";
		$this->colornames['q2'] = "greenname";
		$this->colornames['q3'] = "bluename";
		$this->colornames['q4'] = "purplename";
		$this->colornames['q5'] = "orangename";
		$this->colornames['q6'] = "redname";
		$this->colornames['q'] = "goldtext";
		
		if (!empty($method))
			$this->method = $method;
	}
	
	// Cleans up resources used by this object.
	function close()
	{
		$this->xml_helper->close();
	}

	// Attempts to retrieve data for the specified item from Wowhead.
	function getItem($name)
	{
		global $settings;

		// Ignore blank names.
		$tempname = trim($name);
		if (empty($tempname))
		{
			return null;
		}

		// set default value...
		$item_found = false;
		$item = array('name' => $name);
		$item['source'] = '0';
		$item['method'] = $this->method;
		$item['id'] = '-1';
		
		if (is_numeric($name))
		{
			$this->method = 'id';
		}
		
		if ($this->method =='id')
		{
			$item['method'] = 'id';
			$item['source'] = '2';
			$item_id = intval($name, 10);
		}
		else
		{
			$item['method'] = 'find';
			$item['source'] = '2';
		}

		// Retrieve the XML for this item from Wowhead.
		$xml_data = downloadFile('http://www.wowhead.com/?item=' . str_replace('%20','+',urlencode($name)) . '&xml');			

		if ($xml_data !== false)
		{				
			// ok check if we really got a valid xml file
			$tempname = $this->xml_helper->fetch($xml_data, 'wowhead/item/name');
			$tempicon = $this->xml_helper->fetch($xml_data, 'wowhead/item/icon');

			if ($tempname !== false && $tempicon !== false)
			{
				$item['name'] = itemstats_fixname_dc14($tempname);
				$item['id'] = $this->xml_helper->fetch($xml_data, 'wowhead/item/@id');				
				if ($item['id'] !== false)
				{
					$item['icon'] = $tempicon;
					$item['link'] = $this->xml_helper->fetch($xml_data, 'wowhead/item/link');
					
					if ($item['link'] !== false)
					{
						$item['found'] = '1';
						$item_found = true;
					}
				}
			}
		}
		
		// If a match was found, retrieve additional info about it.		
		if ($item_found)
		{
			// Parse out the display html of this item from the XML
			$item['html'] = $this->xml_helper->fetch($xml_data, 'wowhead/item/htmlTooltip');
			
			if ($item['html'] !== false)
			{
				$item['html'] = str_replace("\r", '', $item['html']);
				$item['html'] = str_replace("\n", '', $item['html']);
				$item['html'] = '<div class="wowitem">' . $item['html'] . '</div>';
				
				// Extract the item color from the HTML.
				preg_match('#<b class="(.*?)">#s', $item['html'], $match);
				$item['color'] = $this->colornames[$match[1]];
				$item['html'] = preg_replace('#<b class="(.*?)">#s', '<b class="'.$item['color'].'">', $item['html']);
				$item['html'] = preg_replace('#<span class="' . $match[1] . '">#s', '<span class="' . $item['color'] . '">', $item['html']);
				$item['html'] = preg_replace('#class="q0(.*?)">#s', 'class="' . $this->colornames['q0'] . '">', $item['html']);
				$item['html'] = preg_replace('#class="q1(.*?)">#s', 'class="' . $this->colornames['q1'] . '">', $item['html']);
				$item['html'] = preg_replace('#class="q2(.*?)">#s', 'class="' . $this->colornames['q2'] . '">', $item['html']);
				$item['html'] = preg_replace('#class="q3(.*?)">#s', 'class="' . $this->colornames['q3'] . '">', $item['html']);
				$item['html'] = preg_replace('#class="q4(.*?)">#s', 'class="' . $this->colornames['q4'] . '">', $item['html']);
				$item['html'] = preg_replace('#class="q5(.*?)">#s', 'class="' . $this->colornames['q5'] . '">', $item['html']);
				$item['html'] = preg_replace('#class="q6(.*?)">#s', 'class="' . $this->colornames['q6'] . '">', $item['html']);
				$item['html'] = preg_replace('#class="q(.*?)">#s', 'class="' . $this->colornames['q'] . '">', $item['html']);
				
				// Fix up the html a bit.
				$item['html'] = str_replace('"', '\'', $item['html']);
				$item['html'] = str_replace("<a", "<a target='_new'", $item['html']);
				
				// Build the final HTML by merging the template and the data we just prepared.
				$template_html = trim(readLocalFile($settings['default_theme_dir'] . '/itemstats/templates/popup.tpl'));
				$item['html'] = str_replace('{ITEM_HTML}', $item['html'], $template_html);
			}
			else
			{
				// If Wowhead was busy or something else went wrong, create some error html.
				$item['icon'] = DEFAULT_ICON_WOWHEAD;
				$item['color'] = 'greyname';
				$item['found'] = '0';
				// Read the template html for an item.
				$template_html = trim(readLocalFile($settings['default_theme_dir'] . '/itemstats/templates/popup-error.tpl'));
				$item['html'] = str_replace('{INFO_SITE}', 'Wowhead', $template_html);	
			}
		}
		else
		{
			// If Wowhead was busy or this item doesn't exist and this item isn't cached yet, create some error html.
			$item['icon'] = DEFAULT_ICON_WOWHEAD;
			$item['color'] = 'greyname';
			$item['found'] = '0';
			// Read the template html for an item.
			$template_html = trim(readLocalFile($settings['default_theme_dir'] . '/itemstats/templates/popup-error.tpl'));
			$item['html'] = str_replace('{INFO_SITE}', 'Wowhead', $template_html);
		}

		return $item;
	}
}
?>