<?php

if (!defined('SMF'))
	die('Hacking attempt...');
	
global $sourcedir;

require_once($sourcedir . '/itemstats/includes/allakhazam.php');
require_once($sourcedir . '/itemstats/includes/buffed.php');
require_once($sourcedir . '/itemstats/includes/wowhead.php');

define('ICON_LINK_PLACEHOLDER', '{ITEM_ICON_LINK}');

// The main interface to the ItemStats module.
class ItemStatsDC14
{
	var $item_cache;
	var $info_site;
	var $source;
	var $method;
	
	// Constructor
	function ItemStatsDC14($source, $method)
	{		
		if ($source == '0')
		{
			$this->info_site = new WoWAllakhazam($method);
		}
		elseif ($source == '1')
		{
			$this->info_site = new WoWBuffed($method);
		}
		else
		{
			$this->info_site = new WoWHeadDC14($method);
		}
		  
		  
		$this->method = $method;		  
		$this->source = $source;
		
		// Setup a ghetto destructor.
		register_shutdown_function(array(&$this, '_ItemStatsDC14'));
	}
	
	// Ghetto Destructor
	function _ItemStatsDC14()
	{
		//$this->item_cache->close();
		$this->info_site->close();
	}
	
	// Returns the properly capitalized name for the specified item.  If the update flag is set and the item is
	// not in the cache, item data item will be fetched from an info site
	function getItemName($name, $update = false)
	{
	  global $settings;
	  
		$proper_name = $settings['wowshared_itemcache']->getItemName($name, $this->source);

		// If this item was not found and the update flag is set, try to fetch the item data from an info site.
		if (empty($proper_name) && $update)
		{
			$this->updateItem($name);
			$proper_name = $settings['wowshared_itemcache']->getItemName($name, $this->source);
		}
		
		return empty($proper_name) ? $name : $proper_name;
	}
	
	// Returns the link to the info site for the specified item.  If the update flag is set and the item is not in
	// the cache, item data will be fetched from an info site
	function getItemLink($name, $update = false)
	{
	  global $settings;
	  
		$link = $settings['wowshared_itemcache']->getItemLink($name);

		// If this item was not found and the update flag is set, try to fetch the item data from an info site.
		if (empty($link) && $update)
		{
			$this->updateItem($name);
			$link = $settings['wowshared_itemcache']->getItemLink($name);
		}

		return $link;
	}
	
	// Returns the color class for the specified item.  If the update flag is set and the item is not in the cache, item
	// data will be fetched from an info site
	function getItemColor($name, $update = false)
	{
	  global $settings;
	  
		$color = $settings['wowshared_itemcache']->getItemColor($name);

		// If this item was not found and the update flag is set, try to fetch the item data from an info site.
		if (empty($color) && $update)
		{
			$this->updateItem($name);
			$color = $settings['wowshared_itemcache']->getItemColor($name);
		}

		return $color;
	}
	
	// Returns the icon link for the specified item.  If the update flag is set and the item is not in the cache, item
	// data will be fetched from an info site
	function getItemIconLink($name, $update = false)
	{
		global $settings;
		
		$icon = $settings['wowshared_itemcache']->getItemIcon($name);

		// If this item was not found and the update flag is set, try to fetch the item data from an info site.
		if (empty($icon) && $update)
		{
			$this->updateItem($name);
			$icon = $settings['wowshared_itemcache']->getItemIcon($name);
		}
		
		// If the icon was found, create a link by merging it with the icon path and extension.
		if (!empty($icon))
		{ 
			$icon_link = $settings['wowicon_store_location'] . $icon . $settings['wowicon_extension'];
		}
		else
		{
			$icon_link = $settings['wowicon_store_location'] . 'INV_Misc_QuestionMark' . $settings['wowicon_extension'];
		}

		return $icon_link;
	}
	
	// Returns the html for the specified item.  If the update flag is set and the item is not in the cache, the
	// item will be fetched from an info site
	function getItemHtml($name, $update = false)
	{
	  global $settings;
	  
		$html = $settings['wowshared_itemcache']->getItemHtml($name);
		
		switch(intval($settings['wowshared_itemcache']->getItemSource($name)))
		{
			case 0:
				if (!strstr($html, "http://wow.allakhazam.com/images/"))
				{
					$html = str_replace("/images/", "http://wow.allakhazam.com/images/", $html);
				}
				break;
			case 1:
				$html = str_replace("/images/", "http://www.buffed.de/images/", $html);
				break;
		}			

		// If this item was not found and the update flag is set, try to fetch the item data from an info site.
		if (empty($html) && $update)
		{
			$this->updateItem($name);
			$html = $settings['wowshared_itemcache']->getItemHtml($name);
		}
		
		// If the item was found, update the icon path in the HTML.
		if (!empty($html))
		{
			$html = str_replace(ICON_LINK_PLACEHOLDER, $this->getItemIconLink($name), $html);
		}

		return $html;
	}
	
	// Returns the overlib tooltip html for the specified item.  If the update flag is set and the item is not in
	// the cache, the item will be fetched from an info site
	function getItemTooltipHtml($name, $update = false)
	{
		// Retrieve the item data from the cache.
		$html = $this->getItemHtml($name, $update);
		if (empty($html))
		{
			return null;
		}

		// Warp the data around the HTML data that invokes the tooltip.
		if (!empty($html))
		{
			// Format the HTML to be compatible with Overlib.
			$html = str_replace(array("\n", "\r"), '', $html);
            $html = str_replace("&apos;", "'", $html);
			$html = addslashes($html);

			$html = 'onmouseover="return overlib(' . "'" . $html . "'" . ',VAUTO,HAUTO,FULLHTML);" onmouseout="return nd(0);"';
		}

		return $html;
	}

	// Retrieves the data for the specified item from an info site and caches it.
	function updateItem($name)
	{
	  global $settings;
	  
		// Retrives the data from an information site.
		$item = $this->info_site->getItem($name);

		// If the item wasn't found, and we have something cached already, don't overwrite with lesser data.
		$cached_link = $this->getItemLink($name);
		if (!empty($item['link']) || empty($cached_link))
		{
			// If the data was loaded succesfully, save it to the cache.
			$result = $settings['wowshared_itemcache']->saveItem($item);
		}

		return $result;
	}
}
?>